@@ -4,8 +4,7 @@
 void IntegrityScanner::execute(string const &cmd)
 {
     if (!(s_firstWord << cmd))          // determine first word and the rest
-        d_stealthLog << "Corrupt line in policy file: " << cmd <<
-                                                        StealthEnums::leave; 
+        fmsg << "Corrupt line in policy file: " << cmd << noidl; 
     else
         m1 << cmd << endl;
     
