@@ -6,6 +6,11 @@ void PolicyFile::fetchCommands()
 {
     directivesAndCommands();
 
+    string &base = d_use["BASE"];
+
+    if (base.back() != '/')
+        base += '/';            
+
     bool ok = d_use.count("SSH");
 
     for(auto &entry: d_define)
@@ -17,13 +22,20 @@ void PolicyFile::fetchCommands()
     for(auto &entry: d_command)
         replaceDefines(entry);
 
-    if (size_t parse = Options::instance().parsePolicyFile())
+    fixRelativeLocations();
+
+    if (size_t parseOnly = d_options.parsePolicy())
     {
-        if (parse > 1)
+        if (parseOnly > 1)
+        {
             for(auto &value: d_use)
                 mp << "USE " << value.first << ": " << value.second << endl;
+        }
 
         mp.clear();
+
+        mp << "REPORT: " << d_use["REPORT"] << endl;
+
         for (size_t idx = 0; idx != d_command.size(); ++idx)
            mp << (idx + 1) << ": " << d_command[idx] << endl;
 
@@ -31,6 +43,11 @@ void PolicyFile::fetchCommands()
     }
 
     if (!ok)
-        fmsg << "USE SSH ... entry missing in the policy file" << endl;
+        fmsg << "USE SSH ... entry missing in the policy file" << noidl;
 }
 
+
+
+
+
+
