@@ -7,12 +7,8 @@ struct StealthEnums
 {
     enum Mode       // uses bit-flags values
     {
-        LEAVE           = 1 << 0,
-
         INTEGRITY_SCAN  = 1 << 1,   // perform an integrity scan
 
-        WAIT            = 1 << 3,   // waiting for another signal/tine
-
         RERUN           = 1 << 4,   // rerun on request at WAITING 
 
         SUSPEND         = 1 << 2,   // suspend a stealth run 
@@ -21,13 +17,12 @@ struct StealthEnums
 
         RELOAD          = 1 << 6,   // reload the config files 
 
-        TERMINATE       = 1 << 7,   // terminate a Stealth run (-> SIGTERM,
-                                    //                             SIGINT)
+        TERMINATE       = 1 << 7,   // terminate a Stealth run
 
-        UNKNOWN         = 1 << 8,   
+        PING            = 1 << 8,   // ping a daemon
+
+        UNKNOWN         = 1 << 9,   
     };
-
-    static std::ostream &leave(std::ostream &out);
 };
 
 inline constexpr StealthEnums::Mode operator|(
@@ -38,5 +33,4 @@ inline constexpr StealthEnums::Mode operator|(
             );
 }
 
-        
 #endif
